#!/usr/bin/env python3

import os
import pathlib
import subprocess

UPDATED = "up to date"
UNWATCHED = "unwatched"
SYNCING = "syncing"

MB = 1024 ** 2

nodes = []


def recurs(directory):
    os.chdir(directory)
    cmd = ['dropbox', 'filestatus']
    proc = subprocess.run(cmd, capture_output=True, encoding='utf8')

    for line in proc.stdout.split('\n'):
        if line.endswith((UPDATED, UNWATCHED)) or not line:
            continue
        assert line.endswith(SYNCING), repr(line)
        line = line[:-len(SYNCING)].strip()
        assert line[-1] == ':'
        node = directory / line[:-1]

        if node.is_dir():
            recurs(node)
        else:
            nodes.append(node)


recurs(pathlib.Path.home() / 'Dropbox')
tot_size = 0
for node in nodes:
    size = node.stat().st_size
    tot_size += size
    print("{:5d} MB {}".format(int(size / MB), node))
print("Total: {} files {} MB".format(len(nodes), int(tot_size / MB)))
